@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-from abc import ABC
+from __future__ import print_function, unicode_literals
 
 
-class CacheAbstract(ABC):
+class CacheAbstract(object):
     """统一的接口
     备注：delete、clear删除动作较为危险，不进行具体实现
     """
